Mirror of the gdb-patches mailing list
 help / color / mirror / Atom feed
* [RFA] Patch to fix "reverse-next" command error
@ 2009-01-22  9:00 teawater
  2009-01-27 17:15 ` Marc Khouzam
  2009-05-06  6:01 ` Hui Zhu
  0 siblings, 2 replies; 20+ messages in thread
From: teawater @ 2009-01-22  9:00 UTC (permalink / raw)
  To: Michael Snyder, Pedro Alves; +Cc: Marc Khouzam, gdb-patches

[-- Attachment #1: Type: text/plain, Size: 668 bytes --]

Hi guys,

This patch is for bug in http://sourceware.org/ml/gdb/2009-01/msg00146.html

This issue is because sometime the inferior is already in function
start address (i.e. plt), set a breakpoint and continue will make
"reverse-next" work error.

This patch make inferior step if it reverse step and stop at the
function start address.
It tested OK with process record patch and testsuite gdb.twreverse in
branch reverse-20081226-branch.

2009-01-22  Hui Zhu  <teawater@gmail.com>

	* infrun.c (handle_inferior_event): Make inferior step if it
	stepping over a function call in reverse , and stop at the
	start address of the function.

OK for mainline?

Thanks,
Hui

[-- Attachment #2: fix-reverse-plt-error.txt --]
[-- Type: text/plain, Size: 1105 bytes --]

Index: gdb/infrun.c
===================================================================
--- gdb.orig/infrun.c	2009-01-22 14:58:31.000000000 +0800
+++ gdb/infrun.c	2009-01-22 16:26:46.000000000 +0800
@@ -3488,10 +3488,21 @@
 		  keep_going (ecs);
 		  return;
 		}
-	      /* Normal (staticly linked) function call return.  */
-	      init_sal (&sr_sal);
-	      sr_sal.pc = ecs->stop_func_start;
-	      insert_step_resume_breakpoint_at_sal (sr_sal, null_frame_id);
+	      if (ecs->stop_func_start != stop_pc)
+		{
+		  /* Normal (staticly linked) function call return.  */
+		  init_sal (&sr_sal);
+		  sr_sal.pc = ecs->stop_func_start;
+		  insert_step_resume_breakpoint_at_sal (sr_sal, null_frame_id);
+		}
+	      else
+		{
+		  /* We are stepping over a function call in reverse, and
+	             stop at the start address of the function.  Go back to
+	             single-stepping, which should take us back to the
+	             function call.  */
+		  ecs->event_thread->stepping_over_breakpoint = 1;
+		}
 	    }
 	  else
 	    insert_step_resume_breakpoint_at_caller (get_current_frame ());

^ permalink raw reply	[flat|nested] 20+ messages in thread

end of thread, other threads:[~2009-06-18 23:56 UTC | newest]

Thread overview: 20+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2009-01-22  9:00 [RFA] Patch to fix "reverse-next" command error teawater
2009-01-27 17:15 ` Marc Khouzam
2009-01-27 23:31   ` Marc Khouzam
2009-01-30 16:25     ` teawater
2009-02-11 19:55       ` Marc Khouzam
2009-02-12  2:59         ` teawater
2009-02-13 16:07           ` Marc Khouzam
2009-02-16 10:26             ` teawater
2009-02-16 19:10               ` Marc Khouzam
2009-02-17  3:58                 ` teawater
2009-02-17 13:10                 ` teawater
2009-03-02  6:11         ` teawater
2009-05-06  6:01 ` Hui Zhu
2009-05-11  7:07   ` Hui Zhu
2009-06-09  2:18     ` Hui Zhu
2009-06-15  2:45       ` Michael Snyder
2009-06-15  6:47         ` Hui Zhu
2009-06-15 15:37           ` Marc Khouzam
2009-06-15 18:04             ` Michael Snyder
2009-06-18 23:56               ` Michael Snyder

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox